@@ -23,6 +23,7 @@
 
 from mingus.core import notes
 from mt_exceptions import NoteFormatError
+from math import log
 
 
 class Note:
@@ -113,6 +114,23 @@ Doesn't change the octave."""
 		"""Calls notes.remove_redundant_accidentals on this note's name."""
 		self.name = notes.remove_redundant_accidentals(self.name)
 
+	def to_hertz(self, standard_pitch = 440):
+		"""Returns the Note in Hz. The `standard_pitch` argument can be used \
+to set the pitch of A-4, from which the rest is calculated."""
+
+		# int(Note("A")) == 57
+		diff = self.__int__() - 57
+		return 2 ** (diff / 12) * 440
+
+	def from_hertz(self, hertz, standard_pitch = 440):
+		"""Sets the Note name and pitch, calculated from the `hertz` value. \
+The `standard_pitch` argument can be used to set the pitch of A-4, from \
+which the rest is calculated."""
+
+		value = log(float(hertz) / standard_pitch, 2) * 12 + notes.note_to_int("A")
+		self.name = notes.int_to_note(int(value) % 12)
+		self.octave = int(value / 12) + 4
+
 	def __int__(self):
 		"""Returns the current octave multiplied by twelve and adds \
 notes.note_to_int to it. This means a C-0 returns 0, C-1 \
